@@ -1,15 +1,14 @@
 ## until we do it for real
 
-#' @title Matrix Print Form - Intermediate Representation for ASCII Table Printing
+#' Class for Matrix Print Form
+#'
+#' The `MatrixPrintForm` class, an intermediate representation for ASCII table printing.
 #'
 #' @name MatrixPrintForm-class
-#'
 #' @rdname MatrixPrintForm_class
-#' @aliases MatrixPrintForm-class
 #' @exportClass MatrixPrintForm
 setOldClass(c("MatrixPrintForm", "list"))
 
-
 mform_handle_newlines <- function(matform) {
   # Retrieving relevant information
   has_topleft <- mf_has_topleft(matform)
@@ -21,7 +20,7 @@ mform_handle_newlines <- function(matform) {
   nl_inds_header <- seq(1, mf_nlheader(matform))
   hdr_inds <- 1:nr_header
 
-  # hack that is necessary only if bottom aligned
+  # hack that is necessary only if top-left is bottom aligned (default)
   topleft_has_nl_char <- FALSE
   if (has_topleft) {
     tl <- strmat[nl_inds_header, 1, drop = TRUE]
@@ -43,6 +42,7 @@ mform_handle_newlines <- function(matform) {
   # nlines detects if there is a newline character
   row_nlines <- apply(strmat, 1, function(x) max(vapply(x, nlines, 1L), 1L))
 
+  # Correction for the case where there are more lines for topleft material than for cols
   if (has_topleft && (sum(row_nlines[nl_inds_header]) < how_many_nl)) {
     row_nlines[1] <- row_nlines[1] + how_many_nl - sum(row_nlines[nl_inds_header])
   }
@@ -92,9 +92,34 @@ mform_handle_newlines <- function(matform) {
     mf_lgrouping(matform) <- rep(line_grouping, times = row_nlines)
   }
 
+  # Solve \n in titles
+  if (any(grepl("\n", all_titles(matform)))) {
+    if (any(grepl("\n", main_title(matform)))) {
+      tmp_title_vec <- .quick_handle_nl(main_title(matform))
+      main_title(matform) <- tmp_title_vec[1]
+      subtitles(matform) <- c(tmp_title_vec[-1], .quick_handle_nl(subtitles(matform)))
+    } else {
+      subtitles(matform) <- .quick_handle_nl(subtitles(matform))
+    }
+  }
+
+  # Solve \n in footers
+  main_footer(matform) <- .quick_handle_nl(main_footer(matform))
+  prov_footer(matform) <- .quick_handle_nl(prov_footer(matform))
+
+  # xxx \n in page titles are not working atm (I think)
+
   matform
 }
 
+.quick_handle_nl <- function(str_v) {
+  if (any(grepl("\n", str_v))) {
+    return(unlist(strsplit(str_v, "\n", fixed = TRUE)))
+  } else {
+    return(str_v)
+  }
+}
+
 # Helper function to recompact the lines following line groupings to then have them expanded again
 .compress_mat <- function(mat, line_grouping, collapse_method = c("nl", "unique")) {
   list_compacted_mat <- lapply(unique(line_grouping), function(lg) {
@@ -142,105 +167,93 @@ disp_from_spans <- function(spans) {
   display
 }
 
-## constructor
-#' @title Matrix Print Form - Intermediate Representation for ASCII Table Printing
+#' Constructor for Matrix Print Form
+#'
+#' Constructor for `MatrixPrintForm`, an intermediate representation for ASCII table printing.
+#'
+#' @param strings (`character matrix`)\cr matrix of formatted, ready-to-display strings
+#'   organized as they will be positioned when rendered. Elements that span more than one
+#'   column must be followed by the correct number of placeholders (typically either empty
+#'   strings or repeats of the value).
+#' @param spans (`numeric matrix`)\cr matrix of same dimension as `strings` giving the
+#'   spanning information for each element. Must be repeated to match placeholders in `strings`.
+#' @param aligns (`character matrix`)\cr matrix of same dimension as `strings` giving the text
+#'   alignment information for each element. Must be repeated to match placeholders in `strings`.
+#'   Must be a supported text alignment. See [decimal_align] for allowed values.
+#' @param formats (`matrix`)\cr matrix of same dimension as `strings` giving the text format
+#'   information for each element. Must be repeated to match placeholders in `strings`.
+#' @param row_info (`data.frame`)\cr data frame with row-information necessary for pagination (see
+#'   [basic_pagdf()] for more details).
+#' @param line_grouping (`integer`)\cr sequence of integers indicating how print lines correspond
+#'   to semantic rows in the object. Typically this should not be set manually unless
+#'   `expand_newlines` is set to `FALSE`.
+#' @param ref_fnotes (`list`)\cr referential footnote information, if applicable.
+#' @param nlines_header (`numeric(1)`)\cr number of lines taken up by the values of the header
+#'   (i.e. not including the divider).
+#' @param nrow_header (`numeric(1)`)\cr number of *rows* corresponding to the header.
+#' @param has_topleft (`flag`)\cr does the corresponding table have "top left information"
+#'   which should be treated differently when expanding newlines. Ignored if `expand_newlines`
+#'   is `FALSE`.
+#' @param has_rowlabs (`flag`)\cr do the matrices (`strings`, `spans`, `aligns`) each contain a
+#'   column that corresponds with row labels (rather than with table cell values). Defaults to `TRUE`.
+#' @param main_title (`string`)\cr main title as a string.
+#' @param subtitles (`character`)\cr subtitles, as a character vector.
+#' @param page_titles (`character`)\cr page-specific titles, as a character vector.
+#' @param main_footer (`character`)\cr main footer, as a character vector.
+#' @param prov_footer (`character`)\cr provenance footer information, as a character vector.
+#' @param listing_keycols (`character`)\cr. if matrix form of a listing, this contains
+#'   the key columns as a character vector.
+#' @param header_section_div (`string`)\cr divider to be used between header and body sections.
+#' @param horizontal_sep (`string`)\cr horizontal separator to be used for printing divisors
+#'   between header and table body and between different footers.
+#' @param expand_newlines (`flag`)\cr whether the matrix form generated should expand rows whose
+#'   values contain newlines into multiple 'physical' rows (as they will appear when rendered into
+#'   ASCII). Defaults to `TRUE`.
+#' @param col_gap (`numeric(1)`)\cr space (in characters) between columns.
+#' @param table_inset (`numeric(1)`)\cr table inset. See [table_inset()].
+#' @param colwidths (`numeric` or `NULL`)\cr column rendering widths. If non-`NULL`, must have length
+#'   equal to `ncol(strings)`.
+#' @param indent_size (`numeric(1)`)\cr number of spaces to be used per level of indent (if supported by
+#'   the relevant method). Defaults to 2.
+#'
+#' @return An object of class `MatrixPrintForm`. Currently this is implemented as an S3 class inheriting
+#'   from list with the following elements:
+#'   \describe{
+#'     \item{`strings`}{see argument.}
+#'     \item{`spans`}{see argument.}
+#'     \item{`aligns`}{see argument.}
+#'     \item{`display`}{logical matrix of same dimension as `strings` that specifies whether an element
+#'       in `strings` will be displayed when the table is rendered.}
+#'     \item{`formats`}{see argument.}
+#'     \item{`row_info`}{see argument.}
+#'     \item{`line_grouping`}{see argument.}
+#'     \item{`ref_footnotes`}{see argument.}
+#'     \item{`main_title`}{see argument.}
+#'     \item{`subtitles`}{see argument.}
+#'     \item{`page_titles`}{see argument.}
+#'     \item{`main_footer`}{see argument.}
+#'     \item{`prov_footer`}{see argument.}
+#'     \item{`header_section_div`}{see argument.}
+#'     \item{`horizontal_sep`}{see argument.}
+#'     \item{`col_gap`}{see argument.}
+#'     \item{`table_inset`}{see argument.}
+#'   }
+#'
+#'   as well as the following attributes:
+#'
+#'   \describe{
+#'     \item{`nlines_header`}{see argument.}
+#'     \item{`nrow_header`}{see argument.}
+#'     \item{`ncols`}{number of columns *of the table*, not including any row names/row labels}
+#'   }
 #'
 #' @note The bare constructor for the `MatrixPrintForm` should generally
-#' only be called by `matrix_form` custom methods, and almost never from other code.
+#'   only be called by `matrix_form` custom methods, and almost never from other code.
+#'
+#' @examples
+#' basic_matrix_form(iris) # calls matrix_form which calls this constructor
 #'
-#' @param  strings character  matrix.  Matrix  of formatted,  ready to
-#'     display  strings  organized as  they  will  be positioned  when
-#'     rendered.   Elements that  span more  than one  column must  be
-#'     followed  by  the  correct number  of  placeholders  (typically
-#'     either empty strings or repeats of the value).
-#' @param  spans  numeric  matrix.    Matrix  of  same  dimension  as
-#'     \code{strings}  giving   the  spanning  information   for  each
-#'     element.    Must  be   repeated   to   match  placeholders   in
-#'     \code{strings}.
-#' @param  aligns character  matrix.   Matrix  of same  dimension  as
-#'     \code{strings} giving  the text alignment information  for each
-#'     element. Must  be   repeated   to   match  placeholders   in
-#'     \code{strings}. Must be a supported text alignment. See
-#'     [decimal_align] allowed values.
-#' @param formats  matrix. Matrix  of same dimension
-#'     as  \code{strings} giving  the text  format information  for
-#'     each  element.   Must  be  repeated to  match  placeholders  in
-#'     \code{strings}.
-#' @param  row_info   data.frame.   Data.frame  with  row-information
-#'     necessary for pagination (XXX document exactly what that is).
-#' @param  line_grouping integer. Sequence of  integers indicating how
-#'     print  lines  correspond  to   semantic  rows  in  the  object.
-#'     Typically   this   should   not    be   set   manually   unless
-#'     `expact_newlines` is set to \code{FALSE}.
-#' @param  ref_fnotes  list.   Referential  footnote  information  if
-#'     applicable.
-#' @param  nlines_header numeric(1). Number  of lines taken up  by the
-#'     values of the header (i.e. not including the divider).
-#' @param nrow_header numeric(1).  Number of \emph{rows} corresponding
-#'     to the header.
-#' @param  has_topleft logical(1).  Does the  corresponding table have
-#'     'top left information' which should be treated differently when
-#'     expanding  newlines.   Ignored   if  \code{expand_newlines}  is
-#'     \code{FALSE}.
-#' @param has_rowlabs  logical(1). Do  the matrices  (\code{strings},
-#'     \code{spans},  \code{aligns})   each  contain  a   column  that
-#'     corresponds  with  row  labels  (Rather than  with  table  cell
-#'     values).  Defaults to \code{TRUE}.
-#' @param main_title character(1). Main title as a string.
-#' @param subtitles character. Subtitles, as a character vector.
-#' @param page_titles character.  Page-specific titles, as a character
-#'     vector.
-#' @param main_footer character(1). Main footer as a string.
-#' @param prov_footer character. Provenance footer information as a
-#'     character vector.
-#' @param header_section_div character(1). Divider to be used between header
-#'     and body sections.
-#' @param horizontal_sep character(1). Horizontal separator to be used for printing
-#'     divisors between header and table body and between different footers.
-#' @param expand_newlines logical(1). Should the matrix form generated
-#'     expand  rows  whose  values   contain  newlines  into  multiple
-#'     'physical'  rows  (as  they  will  appear  when  rendered  into
-#'     ASCII). Defaults to \code{TRUE}
-#' @param col_gap numeric(1). Space (in characters) between columns
-#' @param table_inset numeric(1). Table inset. See
-#' \code{\link{table_inset}}
-#' @param colwidths numeric. NULL, or a vector of column rendering widths.
-#'     if non-NULL, must have length equal to `ncol(strings)`
-#' @param indent_size numeric(1). Number of spaces to be used per level of indent (if supported by
-#' the relevant method). Defaults to 2.
 #' @export
-#' @return An object of class `MatrixPrintForm`. Currently this is
-#' implemented as an S3 class inheriting from list with the following
-#' elements:
-#' \describe{
-#' \item{\code{strings}}{see argument}
-#' \item{\code{spans}}{see argument}
-#' \item{\code{aligns}}{see argument}
-#' \item{\code{display}}{logical matrix of same dimension as `strings`
-#' that specifies whether an element in `strings` will be displayed
-#' when the table is rendered}
-#' \item{\code{formats}}{see argument}
-#' \item{\code{row_info}}{see argument}
-#' \item{\code{line_grouping}}{see argument}
-#' \item{\code{ref_footnotes}}{see argument}
-#' \item{\code{main_title}}{see argument}
-#' \item{\code{subtitles}}{see argument}
-#' \item{\code{page_titles}}{see argument}
-#' \item{\code{main_footer}}{see argument}
-#' \item{\code{prov_footer}}{see argument}
-#' \item{\code{header_section_div}}{see argument}
-#' \item{\code{horizontal_sep}}{see argument}
-#' \item{\code{col_gap}}{see argument}
-#' \item{\code{table_inset}}{see argument}
-#' }
-#'
-#' as well as the following attributes:
-#' \describe{
-#' \item{\code{nlines_header}}{see argument}
-#' \item{\code{nrow_header}}{see argument}
-#' \item{\code{ncols}}{number of columns \emph{of the table}, not including
-#' any row names/row labels}
-#' }
 MatrixPrintForm <- function(strings = NULL,
                             spans,
                             aligns,
@@ -256,6 +269,7 @@ MatrixPrintForm <- function(strings = NULL,
                             main_title = "",
                             subtitles = character(),
                             page_titles = character(),
+                            listing_keycols = NULL,
                             main_footer = "",
                             prov_footer = character(),
                             header_section_div = NA_character_,
@@ -285,6 +299,7 @@ MatrixPrintForm <- function(strings = NULL,
       header_section_div = header_section_div,
       horizontal_sep = horizontal_sep,
       col_gap = col_gap,
+      listing_keycols = listing_keycols,
       table_inset = as.integer(table_inset),
       has_topleft = has_topleft,
       indent_size = indent_size,
@@ -300,7 +315,6 @@ MatrixPrintForm <- function(strings = NULL,
     ret <- mform_handle_newlines(ret)
   }
 
-
   ##  ret <- shove_refdf_into_rowinfo(ret)
   if (is.null(colwidths)) {
     colwidths <- propose_column_widths(ret)
@@ -310,22 +324,22 @@ MatrixPrintForm <- function(strings = NULL,
   ret
 }
 
-
-#' Create a row for a referential footnote information dataframe
+#' Create a row for a referential footnote information data frame
 #'
 #' @inheritParams nlines
-#' @param row_path character. row path (`NA_character_` for none)
-#' @param col_path character. column path (`NA_character_` for none)
-#' @param row integer(1). Integer position of the row.
-#' @param col integer(1). Integer position of the column.
-#' @param symbol character(1). Symbol for the reference. `NA_character_` to use the `ref_index` automatically.
-#' @param ref_index integer(1). The index of the footnote, used for ordering even when symbol is not NA
-#' @param msg character(1). The string message, not including the symbol portion (`{symbol} - `)
+#' @param row_path (`character`)\cr row path (or `NA_character_` for none).
+#' @param col_path (`character`)\cr column path (or `NA_character_` for none).
+#' @param row (`integer(1)`)\cr integer position of the row.
+#' @param col (`integer(1)`)\cr integer position of the column.
+#' @param symbol (`string`)\cr symbol for the reference. `NA_character_` to use the
+#'   `ref_index` automatically.
+#' @param ref_index (`integer(1)`)\cr index of the footnote, used for ordering even when
+#'   symbol is not `NA`.
+#' @param msg (`string`)\cr the string message, not including the symbol portion (`{symbol} - `)
 #'
-#' @return a single row data.frame with the appropriate columns.
+#' @return A single row data frame with the appropriate columns.
 #'
 #' @export
-#'
 ref_df_row <- function(row_path = NA_character_,
                        col_path = NA_character_,
                        row = NA_integer_,
@@ -348,7 +362,6 @@ ref_df_row <- function(row_path = NA_character_,
   )
 }
 
-
 ## this entire thing is a hatchetjob of a hack which should not be necessary.
 ## mf_rinfo(mform) should have the relevant info in it and
 ## mf_cinfo(mform) should be non-null (!!!) and have the info in it
@@ -360,7 +373,6 @@ infer_ref_info <- function(mform, colspace_only) {
     idx <- seq_len(nrow(mf_strings(mform)))
   }
 
-
   hasrlbs <- mf_has_rlabels(mform)
 
   strs <- mf_strings(mform)[idx, , drop = FALSE]
@@ -381,8 +393,6 @@ infer_ref_info <- function(mform, colspace_only) {
   refs_spl <- strsplit(refs_inorder[keepem], ", ", fixed = TRUE)
   runvec <- vapply(refs_spl, length, 1L)
 
-
-
   row_index <- as.vector(
     t(do.call(cbind, replicate(ncol(strs), list(mf_lgrouping(mform)[idx] - mf_nlheader(mform)))))
   )[keepem]
@@ -390,9 +400,6 @@ infer_ref_info <- function(mform, colspace_only) {
   c_torep <- if (hasrlbs) c(NA_integer_, seq(1, ncol(strs) - 1)) else seq_len(ncol(strs))
   col_index <- rep(c_torep, nrow(strs))[keepem]
 
-
-
-
   ret <- data.frame(
     symbol = unlist(refs_spl),
     row_path = I(mf_rinfo(mform)$path[rep(row_index, times = runvec)]),
@@ -404,7 +411,6 @@ infer_ref_info <- function(mform, colspace_only) {
     gsub("^[{][^}]+[}] - ", "", fullmsg)
   }, "")
 
-
   col_pths <- mf_col_paths(mform)
   ret$col_path <- replicate(nrow(ret), list(NA_character_))
   non_na_col <- !is.na(ret$col)
@@ -432,31 +438,19 @@ mform_build_refdf <- function(mform) {
   update_mf_nlines(mform, colwidths = mf_col_widths(mform), max_width = NULL)
 }
 
-
-
-
-
-
-
-
-
-## constructor with snake_case naming convention
-#' @rdname MatrixPrintForm
-#' @export
-matrix_print_form <- MatrixPrintForm
-
-
 ## hide the implementation behind abstraction in case we decide we want a real class someday
-#' `Setters` and `getters` for aspects of `MatrixPrintForm` Objects
+#' Getters and setters for aspects of `MatrixPrintForm` objects
 #'
-#' Most of these functions, particularly the `settters`, are intended
-#' almost exclusively for internal use in, e.g., `matrix_form` methods,
-#' and should generally not be called by end users.
+#' Most of these functions, particularly the setters, are intended almost exclusively for
+#' internal use in, e.g., [`matrix_form`] methods, and should generally not be called by end users.
+#'
+#' @param mf (`MatrixPrintForm`)\cr a `MatrixPrintForm` object.
+#' @param value (`ANY`)\cr the new value for the component in question.
+#'
+#' @return
+#' * Getters return the associated element of `mf`.
+#' * Setters return the modified `mf` object.
 #'
-#' @param mf `MatrixPrintForm(1)`. A `MatrixPrintForm` object
-#' @param value ANY. The new value for the component in question.
-#' @return The element of the `MatrixPrintForm` associated with the `getter`, or
-#' the modified `MatrixPrintForm` object in the case of a `setter`.
 #' @export
 #' @rdname mpf_accessors
 mf_strings <- function(mf) mf$strings
@@ -507,14 +501,10 @@ mf_nlheader <- function(mf) sum(mf_lgrouping(mf) <= mf_nrheader(mf))
 #' @rdname mpf_accessors
 mf_nrheader <- function(mf) attr(mf, "nrow_header", exact = TRUE)
 
-
 #' @export
 #' @rdname mpf_accessors
 mf_colgap <- function(mf) mf$col_gap
 
-
-
-
 ## XXX should this be exported? not sure if there's a point
 mf_col_paths <- function(mf) {
   if (!is.null(mf_cinfo(mf))) {
@@ -524,7 +514,6 @@ mf_col_paths <- function(mf) {
   }
 }
 
-
 mf_col_widths <- function(mf) {
   mf$col_widths
 }
@@ -550,7 +539,6 @@ mf_fnote_df <- function(mf) {
   mf
 }
 
-
 splice_fnote_info_in <- function(df, refdf, row = TRUE) {
   if (NROW(df) == 0) {
     return(df)
@@ -565,7 +553,6 @@ splice_fnote_info_in <- function(df, refdf, row = TRUE) {
   df
 }
 
-
 shove_refdf_into_rowinfo <- function(mform) {
   refdf <- mf_fnote_df(mform)
   rowinfo <- mf_rinfo(mform)
@@ -608,7 +595,6 @@ update_mf_rinfo_extents <- function(mform) {
   )
   stopifnot(all(mapdf$row_num == rinfo$abs_rownumber))
 
-
   new_par_exts <- vapply(rinfo$reprint_inds, function(idx) {
     sum(0L, mapdf$raw_extent[mapdf$row_num %in% idx])
   }, 1L)
@@ -636,8 +622,6 @@ update_mf_ref_nlines <- function(mform, max_width) {
   shove_refdf_into_rowinfo(mform)
 }
 
-
-
 #' @export
 #' @rdname mpf_accessors
 `mf_strings<-` <- function(mf, value) {
@@ -660,7 +644,6 @@ update_mf_ref_nlines <- function(mform, max_width) {
   mf
 }
 
-
 #' @export
 #' @rdname mpf_accessors
 `mf_spans<-` <- function(mf, value) {
@@ -675,7 +658,6 @@ update_mf_ref_nlines <- function(mform, max_width) {
   .chkdim_and_replace(mf, value, component = "aligns")
 }
 
-
 #' @export
 #' @rdname mpf_accessors
 `mf_display<-` <- function(mf, value) {
@@ -689,7 +671,6 @@ update_mf_ref_nlines <- function(mform, max_width) {
   .chkdim_and_replace(mf, value, component = "formats")
 }
 
-
 ## NB NROW(v) == length(v) for atomic vectors so this is ok for lgrouping as wellas rinfo
 .chknrow_and_replace <- function(mf, value, component, noheader = FALSE) {
   strdim <- NROW(mf_strings(mf)) - if (noheader) mf_nlheader(mf) else 0L
@@ -729,24 +710,22 @@ update_mf_ref_nlines <- function(mform, max_width) {
 #' @export
 #' @rdname mpf_accessors
 `mf_cinfo<-` <- function(mf, value) {
-  if (NROW(value) > 0 && NROW(value) != ncol(mf)) {
+  if (NROW(value) > 0 && NROW(value) != mf_ncol(mf)) {
     stop(
       "Number of rows in new cinfo (", NROW(value), ") does not match ",
-      "number of columns (", ncol(mf), ")"
+      "number of columns (", mf_ncol(mf), ")"
     )
   }
   mf$col_info <- value
   mf
 }
 
-
 #' @export
 #' @rdname mpf_accessors
 `mf_lgrouping<-` <- function(mf, value) {
   .chknrow_and_replace(mf, value, component = "line_grouping")
 }
 
-
 #' @export
 #' @rdname mpf_accessors
 `mf_rfnotes<-` <- function(mf, value) {
@@ -754,8 +733,6 @@ update_mf_ref_nlines <- function(mform, max_width) {
   mf
 }
 
-
-
 #' @export
 #' @rdname mpf_accessors
 `mf_nrheader<-` <- function(mf, value) {
@@ -778,8 +755,6 @@ mf_ncol <- function(mf) attr(mf, "ncols", exact = TRUE)
 #' @rdname mpf_accessors
 mf_nrow <- function(mf) max(mf_lgrouping(mf)) - mf_nrheader(mf)
 
-
-
 #' @export
 #' @rdname mpf_accessors
 `mf_ncol<-` <- function(mf, value) {
@@ -805,93 +780,334 @@ mpf_has_rlabels <- function(mf) {
 
 #' @export
 #' @rdname mpf_accessors
-mf_has_rlabels <- function(mf) ncol(mf$strings) > ncol(mf)
+mf_has_rlabels <- function(mf) ncol(mf$strings) > mf_ncol(mf)
 
-#' Create spoof matrix form from a data.frame
+#' Create spoof matrix form from a data frame
 #'
-#' This is  useful primarily  for writing  testing/examples, and as a
-#' starting point for more sophisticated custom `matrix_form` methods
+#' Useful functions for writing tests and examples, and a starting point for
+#' more sophisticated custom `matrix_form` methods.
 #'
-#' @param df data.frame
-#' @param parent_path character. parent path that all rows should be "children of",
-#' defaults to `"root"`, and generally should not matter to end users.
+#' @param df (`data.frame`)\cr a data frame.
+#' @param indent_rownames (`flag`)\cr whether row names should be indented. Being this
+#'   used for testing purposes, it defaults to `FALSE`. If `TRUE`, it assigns label rows
+#'   on even lines (also format is `"-"` and value strings are `""`). Indentation works
+#'   only if split labels are used (see parameters `split_labels` and `data_labels`).
+#' @param parent_path (`string`)\cr parent path that all rows should be "children of".
+#'   Defaults to `NULL`, as usually this is not needed. It may be necessary to use `"root"`,
+#'   for some specific scenarios.
+#' @param ignore_rownames (`flag`)\cr whether row names should be ignored.
+#' @param add_decoration (`flag`)\cr whether adds title and footer decorations should
+#'   be added to the matrix form.
+#' @param split_labels (`string`)\cr indicates which column to use as split labels. If
+#'   `NULL`, no split labels are used.
+#' @param data_labels (`string`)\cr indicates which column to use as data labels. It is
+#'   ignored if no `split_labels` is present and is automatically assigned to
+#'   `"Analysis method"` when `split_labels` is present, but `data_labels` is `NULL`.
+#'   Its direct column name is used as node name in `"DataRow"` pathing. See [mf_rinfo()]
+#'   for more information.
 #'
-#' @return A valid `MatrixPrintForm` object representing `df`,
-#' ready for ASCII rendering
+#' @return A valid `MatrixPrintForm` object representing `df` that is ready for
+#'   ASCII rendering.
+#'
+#' @details
+#' If some of the column has a [obj_format] assigned, it will be respected for all column
+#' values except for label rows, if present (see parameter `split_labels`).
 #'
 #' @examples
 #' mform <- basic_matrix_form(mtcars)
 #' cat(toString(mform))
+#'
+#' # Advanced test case with label rows
+#' library(dplyr)
+#' iris_output <- iris %>%
+#'   group_by(Species) %>%
+#'   summarize("all obs" = round(mean(Petal.Length), 2)) %>%
+#'   mutate("DataRow_label" = "Mean")
+#' mf <- basic_matrix_form(iris_output,
+#'   indent_rownames = TRUE,
+#'   split_labels = "Species", data_labels = "DataRow_label"
+#' )
+#' cat(toString(mf))
+#'
+#' @name test_matrix_form
 #' @export
-basic_matrix_form <- function(df, parent_path = "root") {
-  fmts <- lapply(df, function(x) if (is.null(obj_format(x))) "xx" else obj_format(x))
+basic_matrix_form <- function(df,
+                              indent_rownames = FALSE,
+                              parent_path = NULL,
+                              ignore_rownames = FALSE,
+                              add_decoration = FALSE,
+                              split_labels = NULL,
+                              data_labels = NULL) {
+  checkmate::assert_data_frame(df)
+  checkmate::assert_flag(indent_rownames)
+  checkmate::assert_character(parent_path, null.ok = TRUE)
+  checkmate::assert_flag(ignore_rownames)
+  checkmate::assert_flag(add_decoration)
+  checkmate::assert_character(split_labels, null.ok = TRUE)
+  checkmate::assert_character(data_labels, null.ok = TRUE)
 
-  bodystrs <- mapply(function(x, fmt) {
-    sapply(x, format_value, format = fmt)
-  }, x = df, fmt = fmts)
+  # Some defaults
+  row_classes <- "DataRow" # Default for all rows
+  data_row_format <- "xx" # Default if no labels are used
+  indent_size <- 2
+  indent_space <- paste0(rep(" ", indent_size), collapse = "")
 
-  rnms <- row.names(df)
-  if (is.null(rnms)) {
-    rnms <- as.character(seq_len(NROW(df)))
+  # Pre-processing the fake split
+  if (!is.null(split_labels)) {
+    checkmate::assert_choice(split_labels, colnames(df))
+    label_rows <- as.character(df[[split_labels]])
+    if (is.null(data_labels)) {
+      data_rows <- rep("Analysis Method", nrow(df))
+      data_labels <- "Analyzed Variable"
+    } else {
+      checkmate::assert_choice(data_labels, colnames(df))
+      data_rows <- as.character(df[[data_labels]])
+    }
+    rnms_special <- c(rbind(label_rows, data_rows))
+    row_classes <- c(rbind(
+      rep("LabelRow", length(label_rows)),
+      rep("DataRow", length(data_rows))
+    ))
+    data_colnm <- setdiff(colnames(df), c(split_labels, data_labels))
+    tmp_df <- NULL
+    for (col_i in seq_along(data_colnm)) {
+      lbl_and_dt <- c(rbind(rep("", length(label_rows)), df[[data_colnm[col_i]]]))
+      tmp_df <- cbind(tmp_df, lbl_and_dt)
+    }
+    colnames(tmp_df) <- data_colnm
+    rownames(tmp_df) <- NULL
+    df <- as.data.frame(tmp_df)
+    ignore_rownames <- FALSE
   }
 
-  cnms <- names(df)
+  # Formats
+  fmts <- lapply(df, function(x) {
+    if (is.null(obj_format(x))) {
+      fmt_tmp <- data_row_format
+    } else {
+      fmt_tmp <- obj_format(x) # Can be assigned for each column
+    }
+    out <- rep(fmt_tmp, NROW(df))
+    if (!is.null(split_labels)) {
+      out[row_classes == "LabelRow"] <- "-"
+    }
+    out
+  })
 
-  strings <- rbind(
-    c("", cnms),
-    cbind(rnms, bodystrs)
+  formats <- rbind("", data.frame(fmts))
+  if (!ignore_rownames) {
+    formats <- cbind("rnms" = "", formats)
+  }
+
+  # Strings
+  bodystrs <- mapply(function(x, coli_fmt) {
+    coli_fmt[coli_fmt == "-"] <- "xx"
+    sapply(seq_along(x), function(y) {
+      format_value(x[y], format = coli_fmt[y])
+    })
+  }, x = df, coli_fmt = fmts)
+
+  if (!ignore_rownames) {
+    rnms <- row.names(df)
+    if (!is.null(split_labels)) {
+      # This overload is done because identical rownames not allowed (e.g. Mean.1 Mean.2)
+      rnms <- rnms_special
+    } else if (is.null(rnms)) {
+      rnms <- as.character(seq_len(NROW(df)))
+    }
+  }
+
+  strings <- rbind(colnames(df), bodystrs)
+  rownames(strings) <- NULL
+  if (!ignore_rownames) {
+    strings <- cbind("rnms" = c("", rnms), strings)
+  }
+  # colnames(strings) <- NULL # to add after fixing basic_mf for listings
+
+  # Spans
+  spans <- matrix(1, nrow = nrow(strings), ncol = ncol(strings))
+
+  # Aligns
+  # Default alignment is left for rownames column and center for the rest
+  aligns <- matrix("center",
+    nrow = NROW(strings),
+    ncol = NCOL(strings) - as.numeric(!ignore_rownames)
   )
+  if (!ignore_rownames) {
+    aligns <- cbind("left", aligns)
+  }
 
-  fnr <- nrow(strings)
-  fnc <- ncol(strings)
-
-  ## center alignment for column labels, left alignment for everything else
-  aligns <- rbind(
-    "center",
-    matrix("left", nrow = NROW(df), ncol = fnc)
-  )
-
-
-  ## build up fake pagination df
+  # Row Info: build up fake pagination df
   charcols <- which(sapply(df, is.character))
   if (length(charcols) > 0) {
     exts <- apply(df[, charcols, drop = FALSE], 1, function(x) max(vapply(x, nlines, 1L)))
   } else {
     exts <- rep(1L, NROW(df))
   }
-  rowdf <- basic_pagdf(row.names(df),
-    extents = exts,
-    parent_path = parent_path
-  )
-  formats <- cbind(
-    "",
-    rbind(
-      "",
-      matrix("xx", nrow = nrow(df), ncol = ncol(df))
+  # Constructing path roughly
+  if (!is.null(split_labels)) {
+    paths <- lapply(
+      seq_along(rnms),
+      function(row_path_i) {
+        if (row_classes[row_path_i] == "DataRow") {
+          c(
+            split_labels,
+            rnms[row_path_i - 1], # LabelRow before
+            data_labels,
+            rnms[row_path_i]
+          )
+        } else {
+          c(split_labels, rnms[row_path_i])
+        }
+      }
     )
+  } else {
+    rnms <- row.names(df)
+    if (is.null(rnms)) {
+      rnms <- as.character(seq_len(NROW(df)))
+    }
+    paths <- lapply(rnms, function(x) c(parent_path, x))
+  }
+  rowdf <- basic_pagdf(
+    rnames = rnms,
+    extents = exts,
+    rclass = row_classes,
+    parent_path = NULL, # Overloaded by above parent_path lapply
+    paths = paths
   )
 
-  ret <- matrix_print_form(
+  # Indentation happens last so to be sure we have all ready (only strings and formats change)
+  if (indent_rownames && !is.null(split_labels)) {
+    where_to_indent <- which(row_classes == "DataRow") + 1 # +1 because of colnames
+    strings[where_to_indent, 1] <- paste0(indent_space, strings[where_to_indent, 1])
+    formats[where_to_indent, 1] <- paste0(indent_space, formats[where_to_indent, 1]) # Needs fixing
+    rowdf$indent[where_to_indent - 1] <- 1 # -1 because only rows
+  }
+
+  ret <- MatrixPrintForm(
     strings = strings,
     aligns = aligns,
-    spans = matrix(1, nrow = fnr, ncol = fnc),
+    spans = spans,
     formats = formats, ## matrix("xx", nrow = fnr, ncol = fnc),
     row_info = rowdf,
     has_topleft = FALSE,
     nlines_header = 1,
     nrow_header = 1,
-    has_rowlabs = TRUE
+    has_rowlabs = isFALSE(ignore_rownames),
+    indent_size = indent_size,
   )
-  mform_build_refdf(ret)
+
+  # Check for ncols
+  stopifnot(mf_has_rlabels(ret) == isFALSE(ignore_rownames))
+
+  ret <- mform_build_refdf(ret)
+
+  if (add_decoration) {
+    main_title(ret) <- "main title"
+    main_footer(ret) <- c("main", "  footer")
+    prov_footer(ret) <- "prov footer"
+    subtitles(ret) <- c("sub", "titles")
+  }
+
+  ret
 }
 
+#' @describeIn test_matrix_form Create a `MatrixPrintForm` object from data frame `df` that
+#'   respects the default formats for a listing object.
+#'
+#' @param keycols (`character`)\cr a vector of `df` column names that are printed first and for which
+#'   repeated values are assigned `""`. This format is characteristic of a listing matrix form.
+#'
+#' @return A valid `MatrixPrintForm` object representing `df` as a listing that is ready for ASCII
+#'   rendering.
+#'
+#' @examples
+#' mform <- basic_listing_mf(mtcars)
+#' cat(toString(mform))
+#'
+#' @export
+basic_listing_mf <- function(df,
+                             keycols = names(df)[1],
+                             add_decoration = TRUE) {
+  checkmate::assert_data_frame(df)
+  checkmate::assert_subset(keycols, colnames(df))
+
+  dfmf <- basic_matrix_form(
+    df = df,
+    indent_rownames = FALSE,
+    ignore_rownames = TRUE,
+    add_decoration = add_decoration
+  )
+
+  # keycols addition to MatrixPrintForm (should happen in the constructor)
+  dfmf$listing_keycols <- keycols
+
+  # Modifications needed for making it a listings
+  mf_strings(dfmf)[1, ] <- colnames(mf_strings(dfmf)) # set colnames
+
+  if (!is.null(keycols)) {
+    str_dfmf <- mf_strings(dfmf)[-1, ]
+    # Ordering
+    ord <- do.call(
+      order,
+      as.list(
+        data.frame(
+          str_dfmf[, keycols]
+        )
+      )
+    )
+    str_dfmf <- str_dfmf[ord, ]
+    # Making keycols with empties
+    curkey <- ""
+    for (i in seq_along(keycols)) {
+      kcol <- keycols[i]
+      kcolvec <- str_dfmf[, kcol] # -1 is col label row
+      str_dfmf[, kcol] <- ""
+      kcolvec <- vapply(kcolvec, format_value, "", format = NULL, na_str = "NA")
+      curkey <- paste0(curkey, kcolvec)
+      disp <- c(TRUE, tail(curkey, -1) != head(curkey, -1))
+      str_dfmf[disp, kcol] <- kcolvec[disp]
+    }
+    mf_strings(dfmf)[-1, ] <- str_dfmf
+    # keycols as first
+    mf_strings(dfmf) <- cbind(
+      mf_strings(dfmf)[, keycols, drop = FALSE],
+      mf_strings(dfmf)[, !colnames(mf_strings(dfmf)) %in% keycols, drop = FALSE]
+    )
+  }
+
+  dfmf$aligns[seq(2, nrow(dfmf$aligns)), ] <- "center" # the default for listings
+
+  # the default for listings is a 1 double??
+  dfmf$formats <- matrix(1, nrow = nrow(dfmf$formats), ncol = ncol(dfmf$formats))
+
+  # row info
+  ri <- dfmf$row_info
+  rownames(ri) <- ri$abs_rownumber
+  ri$label <- ri$name <- ""
+  ri$path <- as.list(NA_character_) # same format of listings
+  ri$node_class <- "listing_df"
+  # l_ri$pos_in_siblings # why is it like this in rlistings?? also n_siblings
+  class(ri$path) <- "AsIs" # Artifact from I()
+  dfmf$row_info <- ri
+
+  # colwidths need to be sorted too!!
+  dfmf$col_widths <- dfmf$col_widths[colnames(mf_strings(dfmf))]
+
+  if (!add_decoration) {
+    # This is probably a forced behavior in the original matrix_form in rlistings
+    main_title(dfmf) <- character()
+    main_footer(dfmf) <- character()
+  }
+
+  dfmf
+}
 
 map_to_new <- function(old, map) {
   inds <- match(old, map$old_idx)
   map$new_idx[inds]
 }
 
-
 reconstruct_basic_fnote_list <- function(mf) {
   refdf <- mf_fnote_df(mf)
   if (NROW(refdf) == 0) {
@@ -901,14 +1117,14 @@ reconstruct_basic_fnote_list <- function(mf) {
   paste0("{", refdf$symbol, "} - ", refdf$msg)
 }
 
-.mf_subset_core_mats <- function(mf, i, row = TRUE) {
-  fillnum <- if (row) nrow(mf_strings(mf)) - mf_nlheader(mf) else ncol(mf)
+.mf_subset_core_mats <- function(mf, i, keycols = NULL, row = TRUE) {
+  fillnum <- if (row) nrow(mf_strings(mf)) - mf_nlheader(mf) else mf_ncol(mf)
   if (is.logical(i) || all(i < 0)) {
     i <- seq_len(fillnum)[i]
   }
+  nlh <- mf_nlheader(mf)
 
   if (row) {
-    nlh <- mf_nlheader(mf)
     ncolrows <- mf_nrheader(mf)
     i_mat <- c(seq_len(nlh), which(mf_lgrouping(mf) %in% (i + ncolrows)))
     j_mat <- seq_len(ncol(mf_strings(mf)))
@@ -918,14 +1134,53 @@ reconstruct_basic_fnote_list <- function(mf) {
     j_mat <- c(seq_len(nlabcol), i + nlabcol)
   }
 
+  tmp_strmat <- mf_strings(mf)[i_mat, j_mat, drop = FALSE]
+
+  # Only for listings - Fix pagination with empty values in key columns
+  if (nrow(tmp_strmat) > 0 && .is_listing_mf(mf)) { # safe check for empty listings
+    ind_keycols <- which(colnames(tmp_strmat) %in% keycols)
+
+    # Fix for missing labels in key columns (only for rlistings)
+    empty_keycols <- !nzchar(tmp_strmat[-seq_len(nlh), ind_keycols, drop = FALSE][1, ])
+
+    if (any(empty_keycols)) { # only if there are missing keycol labels
+      # find the first non-empty label in the key columns
+      keycols_needed <- mf_strings(mf)[, empty_keycols, drop = FALSE]
+      first_nonempty <- apply(keycols_needed, 2, function(x) {
+        section_ind <- i_mat[-seq_len(nlh)][1]
+        sec_ind_no_header <- seq_len(section_ind)[-seq_len(nlh)]
+        tail(x[sec_ind_no_header][nzchar(x[sec_ind_no_header])], 1)
+      })
+
+      # if there are only "" the previous returns character()
+      any_chr_empty <- if (length(first_nonempty) > 1) {
+        vapply(first_nonempty, length, numeric(1))
+      } else {
+        length(first_nonempty)
+      }
+      if (any(any_chr_empty == 0L)) {
+        warning(
+          "There are empty key columns in the listing. ",
+          "We keep empty strings for each page."
+        )
+        first_nonempty[any_chr_empty == 0L] <- ""
+      }
+
+      # replace the empty labels with the first non-empty label
+      tmp_strmat[nlh + 1, empty_keycols] <- unlist(first_nonempty)
+    }
+  }
+
+  mf_strings(mf) <- tmp_strmat
 
-  mf_strings(mf) <- mf_strings(mf)[i_mat, j_mat, drop = FALSE]
   mf_lgrouping(mf) <- as.integer(as.factor(mf_lgrouping(mf)[i_mat]))
+
   if (!row) {
-    newspans <- truncate_spans(mf_spans(mf), j_mat) # 'i' is the columns here, b/c row is FALSE
+    newspans <- truncate_spans(mf_spans(mf), j_mat) # 'i' is the columns here, bc row is FALSE
   } else {
     newspans <- mf_spans(mf)[i_mat, j_mat, drop = FALSE]
   }
+
   mf_spans(mf) <- newspans
   mf_formats(mf) <- mf_formats(mf)[i_mat, j_mat, drop = FALSE]
 
@@ -961,16 +1216,15 @@ truncate_spans <- function(spans, j) {
   }
 }
 
-
-mpf_subset_rows <- function(mf, i) {
+mpf_subset_rows <- function(mf, i, keycols = NULL) {
   nlh <- mf_nlheader(mf)
   lgrps <- mf_lgrouping(mf)
   row_lgrps <- tail(lgrps, -1 * nlh)
   nrs <- length(unique(row_lgrps))
   ncolrows <- length(unique(lgrps[seq_len(nlh)]))
 
-  ncs <- ncol(mf)
-  mf <- .mf_subset_core_mats(mf, i, row = TRUE)
+  ncs <- mf_ncol(mf)
+  mf <- .mf_subset_core_mats(mf, i, keycols = keycols, row = TRUE)
   map <- data.frame(
     old_idx = c(seq_len(ncolrows), i + ncolrows),
     new_idx = c(seq_len(ncolrows), ncolrows + order(i))
@@ -997,14 +1251,12 @@ mpf_subset_rows <- function(mf, i) {
   mf
 }
 
-
-
 ## we only care about referential footnotes, cause
 ## they are currently the only place we're tracking
 ## column information that will need to be touched up
 ## but lets be careful and do a bit more anyway
-mpf_subset_cols <- function(mf, j) {
-  nc <- ncol(mf)
+mpf_subset_cols <- function(mf, j, keycols = NULL) {
+  nc <- mf_ncol(mf)
   if (is.logical(j) || all(j < 0)) {
     j <- seq_len(nc)[j]
   }
@@ -1016,15 +1268,13 @@ mpf_subset_cols <- function(mf, j) {
     stop("duplicated columns are not allowed when subsetting a matrix print form objects")
   }
 
-
   #    j_mat <- c(if(mf_has_topleft(mf)) seq_len(nlabcol), j + nlabcol)
   map <- data.frame(old_idx = j, new_idx = order(j))
 
   ## this has to happen before the remap inher
   refdf <- mf_fnote_df(mf)
 
-  mf <- .mf_subset_core_mats(mf, j, row = FALSE)
-
+  mf <- .mf_subset_core_mats(mf, j, keycols = keycols, row = FALSE)
 
   ## future proofing (pipe dreams)
   ## uncomment if we ever manage to have col info information on MPFs
@@ -1035,8 +1285,6 @@ mpf_subset_cols <- function(mf, j) {
   ##     mf_cinfo(mf) <- mf
   ## }
 
-
-
   keep <- is.na(refdf$col) | refdf$col %in% j
   refdf <- refdf[keep, , drop = FALSE]
 
