@@ -1,53 +1,3 @@
-#' @title Default horizontal separator
-#'
-#' @description The default horizontal separator character which can be
-#' displayed in the current `charset` for use in rendering table-likes.
-#'
-#' @param hsep_char character(1). Character that will be set in the R environment
-#'   options as default for creating the horizontal separator. It needs to be
-#'   single character. Use `getOption("formatters_default_hsep")` to get its current
-#'   value (`NULL` if not set).
-#'
-#' @return `unicode` 2014 (long dash for generating solid horizontal line)
-#' if in a locale that uses a UTF character set, otherwise an ASCII hyphen
-#' with a once-per-session warning.
-#'
-#' @examples
-#' default_hsep()
-#' set_default_hsep("o")
-#' default_hsep()
-#'
-#' @name default_horizontal_sep
-#' @export
-default_hsep <- function() {
-  system_default_hsep <- getOption("formatters_default_hsep")
-
-  if (is.null(system_default_hsep)) {
-    if (any(grepl("^UTF", utils::localeToCharset()))) {
-      hsep <- "\u2014"
-    } else {
-      if (interactive()) {
-        warning(
-          "Detected non-UTF charset. Falling back to '-' ",
-          "as default header/body separator. This warning ",
-          "will only be shown once per R session."
-        ) # nocov
-      } # nocov
-      hsep <- "-" # nocov
-    }
-  } else {
-    hsep <- system_default_hsep
-  }
-  hsep
-}
-
-#' @name default_horizontal_sep
-#' @export
-set_default_hsep <- function(hsep_char) {
-  checkmate::assert_character(hsep_char, n.chars = 1, len = 1, null.ok = TRUE)
-  options("formatters_default_hsep" = hsep_char)
-}
-
 .calc_cell_widths <- function(mat, colwidths, col_gap) {
   spans <- mat$spans
   keep_mat <- mat$display
@@ -76,7 +26,6 @@ set_default_hsep <- function(hsep_char) {
   cell_widths_mat
 }
 
-
 # Main function that does the wrapping
 do_cell_fnotes_wrap <- function(mat, widths, max_width, tf_wrap) {
   col_gap <- mf_colgap(mat)
@@ -200,6 +149,7 @@ do_cell_fnotes_wrap <- function(mat, widths, max_width, tf_wrap) {
     ) # nocov
   }
 }
+
 # Helper function that takes out or adds the proper indentation
 .modify_indentation <- function(mat, cell_widths_mat, do_what = c("remove", "add")) {
   # Extract info
@@ -239,7 +189,6 @@ do_cell_fnotes_wrap <- function(mat, widths, max_width, tf_wrap) {
   return(list("mfs" = mfs, "cell_widths_mat" = cell_widths_mat))
 }
 
-
 ## take a character vector and return whether the value is
 ## a string version of a number or not
 is_number_str <- function(vec) {
@@ -258,20 +207,24 @@ is_dec_align <- function(vec) {
 
 any_dec_align <- function(vec) any(is_dec_align(vec))
 
-#' Decimal Alignment
+#' Decimal alignment
 #'
-#' @description Aligning decimal values of string matrix. Allowed alignments are: `dec_left`,
-#'  `dec_right` and `decimal`.
+#' Aligning decimal values of string matrix. Allowed alignments are: `dec_left`, `dec_right`,
+#' and `decimal`.
 #'
-#' @param string_mat character matrix. String matrix component of matrix print form object.
-#' @param align_mat character matrix. Aligns matrix component of matrix print form object.
-#'  Should contain either `dec_left`, `dec_right` or `decimal` for values to be decimal aligned.
+#' @param string_mat (`character matrix`)\cr "string" matrix component of `MatrixPrintForm` object.
+#' @param align_mat (`character matrix`)\cr "aligns" matrix component of `MatrixPrintForm` object.
+#'   Should contain either `dec_left`, `dec_right`, or `decimal` for values to be decimal aligned.
 #'
-#' @details Decimal alignment left and right (`dec_left` and `dec_right`) are different to
-#'  center decimal alignment `decimal` only in the case some padding is present. This may
-#'  happen if column widths are wider by setting parameters `widths` in `toString` or
-#'  `colwidths` in `paginate_*` accordingly. It will be also the case (more common) of
-#'  wider column names. Decimal alignment is not supported along with cell wrapping.
+#' @details Left and right decimal alignment (`dec_left` and `dec_right`) differ from center decimal
+#'   alignment (`decimal`) only when there is padding present. This may occur if column widths are
+#'   set wider via parameters `widths` in `toString` or `colwidths` in `paginate_*`. More commonly,
+#'   it also occurs when column names are wider. Cell wrapping is not supported when decimal
+#'   alignment is used.
+#'
+#' @return A processed string matrix of class `MatrixPrintForm` with decimal-aligned values.
+#'
+#' @seealso [toString()], [MatrixPrintForm()]
 #'
 #' @examples
 #' dfmf <- basic_matrix_form(mtcars[1:5, ])
@@ -279,10 +232,6 @@ any_dec_align <- function(vec) any(is_dec_align(vec))
 #' aligns[, -c(1)] <- "dec_left"
 #' decimal_align(mf_strings(dfmf), aligns)
 #'
-#' @return Processed string matrix of matrix print form with decimal aligned values.
-#'
-#' @seealso [toString] and [MatrixPrintForm]
-#'
 #' @export
 decimal_align <- function(string_mat, align_mat) {
   ## Evaluate if any values are to be decimal aligned
@@ -379,43 +328,34 @@ decimal_align <- function(string_mat, align_mat) {
   string_mat
 }
 
-# toString ---------------------------------------------------------------------
-# main printing code for MatrixPrintForm
-#
+## toString ---------------------------------------------------------------------
+## main printing method for MatrixPrintForm
 
-#' @title Main printing system: `toString`
-#'
 #' @description
-#' All objects that are printed to console pass by `toString`. This function allows
-#' fundamental formatting specifications for the final output, like column widths and
-#' relative wrapping (`width`), title and footer wrapping (`tf_wrap = TRUE` and
-#' `max_width`), or horizontal separator character (e.g. `hsep = "+"`).
+#' All objects that are printed to console pass via `toString`. This function allows
+#' fundamental formatting specifications to be applied to final output, like column widths
+#' and relative wrapping (`width`), title and footer wrapping (`tf_wrap = TRUE` and
+#' `max_width`), and horizontal separator character (e.g. `hsep = "+"`).
 #'
 #' @inheritParams MatrixPrintForm
-#' @param widths numeric (or  `NULL`). (proposed) widths for the columns
-#'     of \code{x}. The expected length  of this numeric vector can be
-#'     retrieved with  `ncol() + 1`  as the  column of row  names must
-#'     also be considered.
-#' @param hsep character(1). Characters to repeat to create
-#'     header/body separator line. If `NULL`, the object value will be
-#'     used. If `" "`, an empty separator will be printed. Check [default_hsep()]
-#'     for more information.
-#' @param tf_wrap logical(1). Should  the texts for  title, subtitle,
-#'     and footnotes be wrapped?
-#' @param max_width integer(1), character(1) or `NULL`. Width that title
-#'     and   footer   (including   footnotes)  materials   should   be
-#'     word-wrapped to. If `NULL`, it is  set to the current print width
-#'     of the  session (`getOption("width")`). If set to `"auto"`,
-#'     the width of the table (plus any table inset) is used. Ignored
-#'     completely if `tf_wrap` is `FALSE`.
+#' @param widths (`numeric` or  `NULL`)\cr Proposed widths for the columns of `x`. The expected
+#'   length of this numeric vector can be retrieved with `ncol(x) + 1` as the column of row names
+#'   must also be considered.
+#' @param hsep (`string`)\cr character to repeat to create header/body separator line. If
+#'   `NULL`, the object value will be used. If `" "`, an empty separator will be printed. See
+#'   [default_hsep()] for more information.
+#' @param tf_wrap (`flag`)\cr whether the text for title, subtitles, and footnotes should be wrapped.
+#' @param max_width (`integer(1)`, `string` or `NULL`)\cr width that title and footer (including
+#'   footnotes) materials should be word-wrapped to. If `NULL`, it is set to the current print width of the
+#'   session (`getOption("width")`). If set to `"auto"`, the width of the table (plus any table inset) is
+#'   used. Parameter is ignored if `tf_wrap = FALSE`.
 #'
 #' @details
+#' Manual insertion of newlines is not supported when `tf_wrap = TRUE` and will result in a warning and
+#' undefined wrapping behavior. Passing vectors of already split strings remains supported, however in this
+#' case each string is word-wrapped separately with the behavior described above.
 #'
-#' Manual insertion of newlines is not supported when `tf_wrap` is on
-#' and will result in a warning and undefined wrapping behavior. Passing
-#' vectors of already split strings remains supported, however in this
-#' case each string is word-wrapped separately with the behavior
-#' described above.
+#' @return A character string containing the ASCII rendering of the table-like object represented by `x`.
 #'
 #' @seealso [wrap_string()]
 #'
@@ -423,9 +363,6 @@ decimal_align <- function(string_mat, align_mat) {
 #' mform <- basic_matrix_form(mtcars)
 #' cat(toString(mform))
 #'
-#' @return A character string containing the ASCII rendering
-#' of the table-like object represented by `x`
-#'
 #' @rdname tostring
 #' @exportMethod toString
 setMethod("toString", "MatrixPrintForm", function(x,
@@ -446,6 +383,12 @@ setMethod("toString", "MatrixPrintForm", function(x,
       "Please contact the maintainer or file an issue."
     ) # nocov
   }
+  if (any(grepl("\r", mf_strings(mat)))) {
+    stop(
+      "Found recursive special characters (\\r) in string matrix produced by matrix_form. ",
+      "This special character is not supported and should be removed."
+    ) # nocov
+  }
 
   # Check that expansion worked for header -> should not happen
   if (!is.null(mf_rinfo(mat)) && # rare case of rtables::rtable()
@@ -494,15 +437,14 @@ setMethod("toString", "MatrixPrintForm", function(x,
   # Total number of characters for the table
   ncchar <- sum(widths) + (length(widths) - 1) * col_gap
 
-  ## Text wrapping checks (widths)
-  if (tf_wrap) {
-    if (is.null(max_width)) {
-      max_width <- getOption("width", 80L)
-    } else if (is.character(max_width) && identical(max_width, "auto")) {
-      max_width <- ncchar + inset
-    }
-    assert_number(max_width, lower = 0)
-  }
+  ## max_width for wrapping titles and footers (not related to ncchar if not indirectly)
+  max_width <- .handle_max_width(
+    tf_wrap = tf_wrap,
+    max_width = max_width,
+    colwidths = widths,
+    col_gap = col_gap,
+    inset = inset
+  )
 
   # Main wrapper function for table core
   mat <- do_cell_fnotes_wrap(mat, widths, max_width = max_width, tf_wrap = tf_wrap)
@@ -548,7 +490,7 @@ setMethod("toString", "MatrixPrintForm", function(x,
     bdy_cont <- tail(content, -nl_header)
     ## unfortunately we count "header rows" wrt line grouping so it
     ## doesn't match the real (i.e. body) rows as is
-    row_grouping <- tail(mf_lgrouping(mat), - nl_header) - mf_nrheader(mat)
+    row_grouping <- tail(mf_lgrouping(mat), -nl_header) - mf_nrheader(mat)
     nrbody <- NROW(bdy_cont)
     stopifnot(length(row_grouping) == nrbody)
     ## all rows with non-NA section divs and the final row (regardless of NA status)
@@ -634,6 +576,38 @@ setMethod("toString", "MatrixPrintForm", function(x,
   )
 })
 
+# Switcher for the 3 options for max_width (NULL, numeric, "auto"))
+.handle_max_width <- function(tf_wrap, max_width,
+                              cpp = NULL, # Defaults to getOption("width", 80L)
+                              # Things for auto
+                              inset = NULL, colwidths = NULL, col_gap = NULL) {
+  max_width <- if (!tf_wrap) {
+    if (!is.null(max_width)) {
+      warning("tf_wrap is FALSE - ignoring non-null max_width value.")
+    }
+    NULL
+  } else if (tf_wrap) {
+    if (is.null(max_width)) {
+      if (is.null(cpp) || is.na(cpp)) {
+        getOption("width", 80L)
+      } else {
+        cpp
+      }
+    } else if (is.numeric(max_width)) {
+      max_width
+    } else if (is.character(max_width) && identical(max_width, "auto")) {
+      # This should not happen, but just in case
+      if (any(sapply(list(inset, colwidths, col_gap), is.null))) {
+        stop("inset, colwidths, and col_gap must all be non-null when max_width is \"auto\".")
+      }
+      inset + sum(colwidths) + (length(colwidths) - 1) * col_gap
+    } else {
+      stop("max_width must be NULL, a numeric value, or \"auto\".")
+    }
+  }
+  return(max_width)
+}
+
 .do_inset <- function(x, inset) {
   if (inset == 0 || !any(nzchar(x))) {
     return(x)
@@ -647,7 +621,6 @@ setMethod("toString", "MatrixPrintForm", function(x,
   x
 }
 
-
 .inset_div <- function(txt, div, inset) {
   c(.do_inset(div, inset), "", txt)
 }
@@ -719,32 +692,25 @@ new_line_warning <- function(str_v) {
   }
 }
 
-
-#' Wrap a string to within a precise width
+#' Wrap a string to a precise width
 #'
-#' @description
-#' Core wrapping functionality that preserve white spaces. Only `"\n"` is not supported
-#' by core functionality [stringi::stri_wrap()]. This is usually solved before hand by
-#' [matrix_form()]. If the width is smaller than any large word, these will be truncated
-#' after `width` characters. If the split leaves trailing groups of empty spaces,
-#' they will be dropped.
+#' Core wrapping functionality that preserves whitespace. Newline character `"\n"` is not supported
+#' by core functionality [stringi::stri_wrap()]. This is usually solved beforehand by [matrix_form()].
+#' If the width is smaller than any large word, these will be truncated after `width` characters. If
+#' the split leaves trailing groups of empty spaces, they will be dropped.
 #'
-#' @param str character. String to be wrapped. If it is a character vector or
-#'   a list, it will be looped as a list and returned with `unlist(use.names = FALSE)`.
-#' @param width numeric(1). Width, in characters, that the
-#'   text should be wrapped at.
-#' @param collapse character(1) or `NULL`. If the words that have been split should
-#'   be pasted together with the collapse character. This is usually done internally
-#'   with `"\n"` to have the wrapping updated along with other internal values.
+#' @param str (`string`, `character`, or `list`)\cr string to be wrapped. If it is a `vector` or
+#'   a `list`, it will be looped as a `list` and returned with `unlist(use.names = FALSE)`.
+#' @param width (`numeric(1)`)\cr width, in characters, that the text should be wrapped to.
+#' @param collapse (`string` or `NULL`)\cr collapse character used to separate segments of words that
+#'   have been split and should be pasted together. This is usually done internally with `"\n"` to update
+#'   the wrapping along with other internal values.
 #'
-#' @details Word wrapping happens as with [stringi::stri_wrap()]
-#'   with the following exception: individual words which are longer
-#'   than `max_width` are broken up in a way that fits with the rest of the
-#'   word wrapping.
+#' @details Word wrapping happens similarly to [stringi::stri_wrap()] with the following difference: individual
+#'   words which are longer than `max_width` are broken up in a way that fits with other word wrapping.
 #'
-#' @return A string if `str` is one element and if `collapse = NULL`. Otherwise, is
-#'   a list of elements (if `length(str) > 1`) that can contain strings or vector of
-#'   characters (if `collapse = NULL`).
+#' @return A string if `str` is one element and if `collapse = NULL`. Otherwise, a list of elements
+#'   (if `length(str) > 1`) that can contain strings or vectors of characters (if `collapse = NULL`).
 #'
 #' @examples
 #' str <- list(
@@ -753,7 +719,6 @@ new_line_warning <- function(str_v) {
 #' )
 #' wrap_string(str, 5, collapse = "\n")
 #'
-#' @name wrap_string
 #' @export
 wrap_string <- function(str, width, collapse = NULL) {
   if (length(str) > 1) {
@@ -820,8 +785,8 @@ wrap_string <- function(str, width, collapse = NULL) {
       broken_char_ori <- sum(nchar(ori_wrapped_txt_v) > width) # how many issues there were
       broken_char_cur <- sum(nchar(cur_wrapped_txt_v) > width) # how many issues there are
 
-      if (setequal(ori_wrapped_txt_v, cur_wrapped_txt_v) ||
-          broken_char_cur >= broken_char_ori) { # we did not solve the current issue!
+      # if still broken, we did not solve the current issue!
+      if (setequal(ori_wrapped_txt_v, cur_wrapped_txt_v) || broken_char_cur >= broken_char_ori) {
         # help function: Very rare case where the recursion is stuck in a loop
         ret_tmp <- force_split_words_by(ret[we_interval], width) # here we_interval is only one ind
         ret <- append(ret, ret_tmp, we_interval)[-we_interval]
@@ -885,8 +850,8 @@ split_words_by <- function(wrd, width) {
   }, character(1), USE.NAMES = FALSE)
 }
 
-#' @describeIn wrap_string function that flattens the list of wrapped strings with
-#'   `unist(str, use.names = FALSE)`. This is deprecated, use [wrap_string()] instead.
+#' @describeIn wrap_string Deprecated function. Please use [wrap_string()] instead.
+#'
 #' @examples
 #' wrap_txt(str, 5, collapse = NULL)
 #'
@@ -915,7 +880,6 @@ rep_vec_to_len <- function(vec, len, ...) {
   )
 }
 
-
 safe_strsplit <- function(x, split, ...) {
   ret <- strsplit(x, split, ...)
   lapply(ret, function(reti) if (length(reti) == 0) "" else reti)
@@ -941,33 +905,32 @@ expand_mat_rows <- function(mat, row_nlines = apply(mat, 1, nlines), expfun = pa
   do.call(rbind, exprows)
 }
 
-
-#' Transform vectors of spans (with duplication) to Visibility vector
+#' Transform a vector of spans (with duplication) into a visibility vector
 #'
-#' @param spans numeric. A vector of spans, with each span value repeated
-#' for the cells it covers.
+#' @param spans (`numeric`)\cr a vector of spans, with each span value repeated
+#'   for the cells it covers.
 #'
 #' @details
+#' The values of `spans` are assumed to be repeated such that each individual position covered by the
+#' span has the repeated value.
 #'
-#' The values of \code{spans} are assumed to be repeated to such that
-#' each individual position covered by the span has the repeated value.
+#' This means that each block of values in `spans` must be of a length at least equal to its value
+#' (i.e. two 2s, three 3s, etc).
 #'
-#' This means that each block of values in \code{span} must be of a length
-#' at least equal to its value (i.e. two 2s, three 3s, etc).
+#' This function correctly handles cases where two spans of the same size are next to each other;
+#' i.e., a block of four 2s represents two large cells each of which spans two individual cells.
+#'
+#' @return A logical vector the same length as `spans` indicating whether the contents of a string vector
+#'   with those spans is valid.
 #'
-#' This function correctly handles cases where two spans of the same size
-#' are next to each other; i.e., a block of four 2s represents two large
-#' cells each of which span two individual cells.
-#' @export
 #' @note
+#' Currently no checking or enforcement is done to verify that the vector of spans is valid according to
+#' the specifications described in the Details section above.
 #'
-#' Currently no  checking or  enforcement is done  that the  vector of
-#' spans is valid in the sense described in the Details section above.
 #' @examples
-#'
 #' spans_to_viscell(c(2, 2, 2, 2, 1, 3, 3, 3))
-#' @return a logical vector the same length as `spans` indicating
-#' whether the contents of a string vector with those spans
+#'
+#' @export
 spans_to_viscell <- function(spans) {
   if (!is.vector(spans)) {
     spans <- as.vector(spans)
@@ -986,40 +949,21 @@ spans_to_viscell <- function(spans) {
   )
 }
 
-
-#' Propose Column Widths based on an object's `MatrixPrintForm` form
+#' Propose column widths based on the `MatrixPrintForm` of an object
 #'
-#' The row names are also considered a column for the output
+#' Row names are also considered a column for the output.
 #'
-#' @param x `MatrixPrintForm` object, or an object with a `matrix_form`
-#' method.
-#' @param indent_size numeric(1). Indent size in characters. Ignored
-#' when `x` is already a `MatrixPrintForm` object in favor of information
-#' there.
+#' @param x (`ANY`)\cr a `MatrixPrintForm` object, or an object with a `matrix_form` method.
+#' @param indent_size (`numeric(1)`)\cr indent size, in characters. Ignored when `x` is already
+#'   a `MatrixPrintForm` object in favor of information there.
+#'
+#' @return A vector of column widths based on the content of `x` for use in printing and pagination.
 #'
 #' @examples
 #' mf <- basic_matrix_form(mtcars)
 #' propose_column_widths(mf)
 #'
 #' @export
-#' @return a vector of column widths based on the content of \code{x}
-#' for use in printing and pagination.
-## ' @examples
-## ' library(dplyr)
-## ' library(rtables)
-## ' iris2 <- iris %>%
-## '   group_by(Species) %>%
-## '   mutate(group = as.factor(rep_len(c("a", "b"), length.out = n()))) %>%
-## '   ungroup()
-## '
-## ' l <- basic_table() %>%
-## '   split_cols_by("Species") %>%
-## '   split_cols_by("group") %>%
-## '   analyze(c("Sepal.Length", "Petal.Width"), afun = list_wrap_x(summary) , format = "xx.xx")
-## '
-## ' tbl <- build_table(l, iris2)
-## ' mf <- matrix_form(tbl)
-## ' propose_column_widths(mf)
 propose_column_widths <- function(x, indent_size = 2) {
   if (!is(x, "MatrixPrintForm")) {
     x <- matrix_form(x, indent_rownames = TRUE, indent_size = indent_size)
@@ -1072,32 +1016,28 @@ propose_column_widths <- function(x, indent_size = 2) {
   widths
 }
 
-
-
-
 #' Pad a string and align within string
 #'
-#' @param x string
-#' @param n number  of  character  of the  output  string,  if `n  <
-#'     nchar(x)` an error is thrown
-#' @param just  character(1).   Text  alignment   justification  to
-#'     use. Defaults to `center`. Must be `center`, `right`, `left`,
-#'     `dec_right`, `dec_left` or `decimal`.
+#' @param x (`string`)\cr a string.
+#' @param n (`integer(1)`)\cr number of characters in the output string. If `n < nchar(x)`, an error is thrown.
+#' @param just (`string`)\cr text alignment justification to use. Defaults to `"center"`. Must be one of
+#'   `"center"`, `"right"`, `"left"`, `"dec_right"`, `"dec_left"`, or `"decimal"`.
+#'
+#' @return `x`, padded to be a string of length `n`.
 #'
-#' @export
 #' @examples
-#'
 #' padstr("abc", 3)
 #' padstr("abc", 4)
 #' padstr("abc", 5)
 #' padstr("abc", 5, "left")
 #' padstr("abc", 5, "right")
 #'
-#' if (interactive()) {
-#'   padstr("abc", 1)
+#' \dontrun{
+#' # Expect error: "abc" has more than 1 characters
+#' padstr("abc", 1)
 #' }
-#' @return `x`, padded to be a string of `n` characters
 #'
+#' @export
 padstr <- function(x, n, just = list_valid_aligns()) {
   just <- match.arg(just)
 
@@ -1130,20 +1070,18 @@ spaces <- function(n) {
   strrep(" ", n)
 }
 
-
 .paste_no_na <- function(x, ...) {
   paste(na.omit(x), ...)
 }
 
-
-#' spread `x` into `len` elements
+#' Spread an integer to a given length
 #'
-#' @param x numeric(1). The number to spread
-#' @param len numeric(1). The number of times to repeat \code{x}
+#' @param x (`integer(1)`)\cr number to spread.
+#' @param len (`integer(1)`)\cr number of times to repeat `x`.
+#'
+#' @return If `x` is a scalar whole number value (see [is.wholenumber()]), the value `x` is repeated `len` times.
+#'   Otherwise, an error is thrown.
 #'
-#' @export
-#' @return if \code{x} is a scalar "whole number" value (see \code{\link{is.wholenumber}}),
-#' the value \code{x} repeated \code{len} times. If not, an error is thrown.
 #' @examples
 #' spread_integer(3, 1)
 #' spread_integer(0, 3)
@@ -1154,6 +1092,8 @@ spaces <- function(n) {
 #' spread_integer(5, 3)
 #' spread_integer(6, 3)
 #' spread_integer(7, 3)
+#'
+#' @export
 spread_integer <- function(x, len) {
   stopifnot(
     is.wholenumber(x), length(x) == 1, x >= 0,
@@ -1161,7 +1101,6 @@ spread_integer <- function(x, len) {
     !(len == 0 && x > 0)
   )
 
-
   if (len == 0) {
     integer(0)
   } else {
@@ -1179,22 +1118,19 @@ spread_integer <- function(x, len) {
   }
 }
 
-
-
-#' `is.wholenumber`
+#' Check if a value is a whole number
 #'
-#' @param x numeric(1). A numeric value
-#' @param tol numeric(1). A precision tolerance.
+#' @param x (`numeric(1)`)\cr a numeric value.
+#' @param tol (`numeric(1)`)\cr a precision tolerance.
 #'
-#' @return \code{TRUE} if \code{x} is within \code{tol} of zero,
-#' \code{FALSE} otherwise.
+#' @return `TRUE` if `x` is within `tol` of zero, `FALSE` otherwise.
 #'
-#' @export
 #' @examples
 #' is.wholenumber(5)
 #' is.wholenumber(5.00000000000000001)
 #' is.wholenumber(.5)
 #'
+#' @export
 is.wholenumber <- function(x, tol = .Machine$double.eps^0.5) {
   abs(x - round(x)) < tol
 }
