@@ -9,7 +9,6 @@ test_that("pagination works", {
     ftmsg
   )
 
-
   ## min_siblings following siblings test
   pagindices <- pag_indices_inner(
     mf_rinfo(dfmf),
@@ -64,14 +63,14 @@ test_that("pagination works", {
   ##                                min_siblings = 0,
   ##                                verbose = TRUE))
 
-  expect_error(
-    paginate_to_mpfs(
+  expect_identical(
+    length(paginate_to_mpfs(
       dfmf_cont,
       lpp = 8 + 2,
       min_siblings = 0,
       verbose = TRUE
-    ),
-    "Unable to find any valid pagination"
+    )),
+    7L
   )
 
   ## https://github.com/insightsengineering/rtables/issues/318
@@ -85,7 +84,6 @@ test_that("pagination works", {
     matrix(c("", "tleft mats", "m", "pg"), nrow = 2, ncol = 2)
   )
 
-
   ## https://github.com/insightsengineering/formatters/issues/77
 
   dfmf3 <- dfmf
@@ -93,9 +91,6 @@ test_that("pagination works", {
   str <- toString(dfmf3)
   expect_true(grepl("Volvo 142E", str))
 
-
-
-
   strout <- toString(dfmf)
   expect_true(any(grepl(ftmsg, strout)))
 
@@ -127,7 +122,6 @@ test_that("pagination works", {
   )
   expect_true(all(sapply(hpagmpfs, function(x) max(mf_lgrouping(x)) - mf_nrheader(x)) == 2L))
 
-
   ## vpaginds <- vert_pag_indices(df2mf, cpp = 40, verbose = TRUE)
 
   ## expect_identical(
@@ -180,7 +174,6 @@ test_that("pagination works", {
     rep(1L, 5)
   )
 
-
   ## they all appear
   expect_equal(
     sort(unique(unlist(vpaginds3))),
@@ -210,7 +203,6 @@ test_that("pagination works", {
   expect_false(grepl("1[[:space:]]*1", strout))
   expect_true(grepl("3[[:space:]]*3", strout))
 
-
   expect_identical(
     spread_integer(7, 3),
     c(3, 2, 2)
@@ -237,8 +229,6 @@ test_that("pagination works", {
   expect_identical(nlines(NULL), 0L)
   expect_identical(nlines("hi\nthere"), 2L)
 
-
-
   ## coverage for handling of ref footnotes in pagination machinery
   ## also covered partially in closely related export test
 
@@ -284,7 +274,6 @@ test_that("pagination works", {
 
   expect_identical(page_lcpp(pg_width = 4, pg_height = 4, margins = rep(0, 4)), list(cpp = 60, lpp = 36))
 
-
   ## first vertical pagination is "forced" after row 1,
   ## 2 additional vertical paginations within second "forced page" (3 total)
   ## 3 horizontal paginations
@@ -325,6 +314,7 @@ test_that("pagination works", {
     TRUE
   })
 })
+
 test_that("page to lcpp stuff works", {
   expect_identical(
     page_lcpp(margins = c(
@@ -340,7 +330,6 @@ test_that("page to lcpp stuff works", {
   )
 })
 
-
 test_that("non-monospaced fonts are caught", {
   ## non-monospaced fonts
   expect_error(page_lcpp(font_family = "Times"), "does not appear to be monospaced")
@@ -364,3 +353,107 @@ test_that("spans and string matrix match after pagination when table has single
     dim(pag_test[[1]]$strings)
   )
 })
+
+test_that("pag_num works in paginate_to_mpfs and export_as_txt", {
+  tst <- basic_matrix_form(mtcars, add_decoration = TRUE)
+  pg_tst <- paginate_to_mpfs(tst, page_num = TRUE)
+
+  print_pg_tst <- lapply(pg_tst, function(x) strsplit(toString(x), "\n")[[1]])
+
+  expect_equal(nchar(print_pg_tst[[1]][46]), 105) # 105 seems the default
+
+  pg_tst <- paginate_to_mpfs(tst, cpp = 50, lpp = 20, page_num = "Non fixed Paging {i} of {n}")
+
+  print_pg_tst <- lapply(pg_tst, function(x) strsplit(toString(x), "\n")[[1]])
+
+  # lpp is respected
+  expect_true(all(sapply(lengths(print_pg_tst), function(x) x <= 20)))
+
+  # cpp is respected exactly for last line (pages)
+  expect_true(all(sapply(print_pg_tst, function(x) nchar(tail(x, 1)) == 50)))
+
+  # page_num is respected
+  expect_identical(
+    print_pg_tst[[1]][20],
+    "                          Non fixed Paging 1 of 18"
+  )
+  expect_identical(
+    print_pg_tst[[4]][20],
+    "                          Non fixed Paging 4 of 18"
+  )
+
+  # lets go to the minimum cpp and break it -> propose_column_widths(tst)
+  expect_error(
+    pg_tst_off <- paginate_to_mpfs(tst,
+      cpp = 19 + 5 + 3, # rownames + max colwidths + 3 (extra colgap)
+      lpp = 20,
+      page_num = "This is too long, it is breaking"
+    ),
+    "Page numbering string \\(page_num\\) is too wide to fit the desired page size width \\(cpp\\)."
+  )
+
+  # Very stringent test with export_as_txt
+  pg_tst_exp <- export_as_txt(tst,
+    cpp = 50, lpp = 20,
+    page_num = "Non fixed Paging {i} of {n}",
+    page_break = "OoOoO"
+  )
+  pages_tst_exp <- lapply(strsplit(pg_tst_exp, "OoOoO")[[1]], function(x) strsplit(x, "\n")[[1]])
+  expect_equal(pages_tst_exp, print_pg_tst)
+})
+
+
+test_that("colwidths and num_rep_cols work when using lists of tables and listings", {
+  bmf <- basic_matrix_form(mtcars, ignore_rownames = TRUE)
+  blmf <- basic_listing_mf(mtcars, keycols = c("vs", "gear"))
+  expect_equal(num_rep_cols(bmf), 0L)
+  expect_equal(num_rep_cols(blmf), 2L)
+
+  l_mf <- list(bmf, blmf)
+
+  output <- export_as_txt(l_mf, page_num = "page {i} of {n}", cpp = 90, colwidths = rep(8, 11))
+  nchar_lines <- sapply(strsplit(output, "\n")[[1]], nchar)
+
+  expect_equal(max(nchar_lines), 90)
+  expect_true(grepl(names(nchar_lines)[length(nchar_lines)], pattern = "page 4 of 4"))
+  expect_equal(unname(nchar_lines[length(nchar_lines)]), 90) # last line is full (page number)
+
+  sorted_tnl <- sort(table(nchar_lines), decreasing = TRUE)
+
+  expect_equal(unname(sorted_tnl[names(sorted_tnl) == "90"]), 4) # there are 4 pages (with page number)
+  expect_equal(names(sorted_tnl[c(1, 2)]), c("85", "52"))
+
+  expect_error(
+    export_as_txt(l_mf, colwidths = rep(8, 10)),
+    "non-null colwidths argument must have length ncol"
+  )
+
+  expect_silent(
+    output <- export_as_txt(l_mf, page_num = "page {i} of {n}", cpp = 90, colwidths = rep(8, 11), num_rep_cols = 2)
+  )
+})
+
+test_that("rep_cols works as intended for listings and tables", {
+  bmf <- basic_matrix_form(mtcars, ignore_rownames = FALSE)
+  blmf <- basic_listing_mf(mtcars, keycols = c("vs", "gear"))
+  expect_equal(num_rep_cols(bmf), 0L) # repeated rowlabels are excluded from num_rep_cols
+  expect_equal(num_rep_cols(blmf), 2L)
+
+  out <- export_as_txt(bmf, rep_cols = 2, cpp = 90) %>%
+    strsplit("\n") %>%
+    unlist()
+  expect_true(grepl(out[35], pattern = "mpg")) # mpg is repeated
+  expect_true(grepl(out[35], pattern = "cyl")) # cyl is repeated
+
+  out <- export_as_txt(blmf, cpp = 70) %>%
+    strsplit("\n") %>%
+    unlist()
+  expect_true(grepl(out[51], pattern = "vs")) # vs is repeated
+  expect_true(grepl(out[51], pattern = "gear")) # gear is repeated
+
+  out <- export_as_txt(blmf, rep_cols = 1, cpp = 70) %>%
+    strsplit("\n") %>%
+    unlist()
+  expect_true(grepl(out[51], pattern = "vs")) # vs is repeated
+  expect_false(grepl(out[51], pattern = "gear")) # gear is NOT repeated
+})
